import Taro from '@tarojs/taro'

/**
 * object 转 queryStr
 * @param {*} params 
 * @returns 
 */
 export function getQueryString (params) {
  if (!params) return;

  const keys = Object.keys(params)
  const arr = keys.map((key) => {
    const val = params[key]
    if (val === null || val === undefined) return false;

    return `${key}=${encodeURIComponent(val)}`
  })

  return arr.filter(Boolean).join('&')
}


export default (url, options) => {
  const { params, skipError, header, ...leftOptions } = options || {}
  const queryStr = getQueryString(params)

  const urlWithParams = queryStr ? `${url}?${queryStr}` : url;
  // eslint-disable-next-line no-undef
  const nwUrl = `${HOST}/api/${urlWithParams}`

  const authToken = Taro.getStorageSync('token')
  const tokenHeader = authToken ? { Authorization: authToken } : {}
  const nwHeader = {
    ...(header || {}),
    ...tokenHeader,
  }

  return new Promise((resolve, reject) => {
    Taro.request({
      ...leftOptions,
      url: nwUrl,
      header: nwHeader,
      success: (res) => {
        const { code, message, data, token } = res.data

        if (token || data?.token) {
          Taro.setStorage({ key: 'token', data: token || data?.token })
        }

        if (code === 1000) {
          resolve(data)

        } else {
          if (!skipError) {
            Taro.showToast({
              title: message || '网络异常',
              icon: 'none',
            })
          }
          reject(message?.indexOf('java') > -1 ? '系统内部错误' : message)
        }
      },

      fail: (err) => {
        console.error(err)

        const message = err.message || err.errMsg || err

        if (!skipError) {
          Taro.showToast({
            title: message,
            icon: 'none',
          })
        }

        reject(message)
      }
    })
  })
}
